/*******************************************************************************
* File Name: BT_Receiver.h
* Version 2.30
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_BT_Receiver_H)
#define CY_UART_BT_Receiver_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

#define BT_Receiver_RX_ENABLED                     (1u)
#define BT_Receiver_TX_ENABLED                     (1u)
#define BT_Receiver_HD_ENABLED                     (0u)
#define BT_Receiver_RX_INTERRUPT_ENABLED           (0u)
#define BT_Receiver_TX_INTERRUPT_ENABLED           (0u)
#define BT_Receiver_INTERNAL_CLOCK_USED            (0u)
#define BT_Receiver_RXHW_ADDRESS_ENABLED           (0u)
#define BT_Receiver_OVER_SAMPLE_COUNT              (8u)
#define BT_Receiver_PARITY_TYPE                    (0u)
#define BT_Receiver_PARITY_TYPE_SW                 (0u)
#define BT_Receiver_BREAK_DETECT                   (0u)
#define BT_Receiver_BREAK_BITS_TX                  (13u)
#define BT_Receiver_BREAK_BITS_RX                  (13u)
#define BT_Receiver_TXCLKGEN_DP                    (1u)
#define BT_Receiver_USE23POLLING                   (1u)
#define BT_Receiver_FLOW_CONTROL                   (0u)
#define BT_Receiver_CLK_FREQ                       (0u)
#define BT_Receiver_TXBUFFERSIZE                   (4u)
#define BT_Receiver_RXBUFFERSIZE                   (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_30 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#ifdef BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define BT_Receiver_CONTROL_REG_REMOVED            (0u)
#else
    #define BT_Receiver_CONTROL_REG_REMOVED            (1u)
#endif /* End BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct BT_Receiver_backupStruct_
{
    uint8 enableState;

    #if(BT_Receiver_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End BT_Receiver_CONTROL_REG_REMOVED */
    #if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
        uint8 rx_period;
        #if (CY_UDB_V0)
            uint8 rx_mask;
            #if (BT_Receiver_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End BT_Receiver_RXHW_ADDRESS_ENABLED */
        #endif /* End CY_UDB_V0 */
    #endif  /* End (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED)*/

    #if(BT_Receiver_TX_ENABLED)
        #if(BT_Receiver_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (CY_UDB_V0)
                uint8 tx_clk_compl;
            #endif  /* End CY_UDB_V0 */
        #else
            uint8 tx_period;
        #endif /*End BT_Receiver_TXCLKGEN_DP */
        #if (CY_UDB_V0)
            uint8 tx_mask;
        #endif  /* End CY_UDB_V0 */
    #endif /*End BT_Receiver_TX_ENABLED */
} BT_Receiver_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void BT_Receiver_Start(void) ;
void BT_Receiver_Stop(void) ;
uint8 BT_Receiver_ReadControlRegister(void) ;
void BT_Receiver_WriteControlRegister(uint8 control) ;

void BT_Receiver_Init(void) ;
void BT_Receiver_Enable(void) ;
void BT_Receiver_SaveConfig(void) ;
void BT_Receiver_RestoreConfig(void) ;
void BT_Receiver_Sleep(void) ;
void BT_Receiver_Wakeup(void) ;

/* Only if RX is enabled */
#if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )

    #if(BT_Receiver_RX_INTERRUPT_ENABLED)
        void  BT_Receiver_EnableRxInt(void) ;
        void  BT_Receiver_DisableRxInt(void) ;
        CY_ISR_PROTO(BT_Receiver_RXISR);
    #endif /* BT_Receiver_RX_INTERRUPT_ENABLED */

    void BT_Receiver_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void BT_Receiver_SetRxAddress1(uint8 address) ;
    void BT_Receiver_SetRxAddress2(uint8 address) ;

    void  BT_Receiver_SetRxInterruptMode(uint8 intSrc) ;
    uint8 BT_Receiver_ReadRxData(void) ;
    uint8 BT_Receiver_ReadRxStatus(void) ;
    uint8 BT_Receiver_GetChar(void) ;
    uint16 BT_Receiver_GetByte(void) ;
    uint8 BT_Receiver_GetRxBufferSize(void)
                                                            ;
    void BT_Receiver_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define BT_Receiver_GetRxInterruptSource   BT_Receiver_ReadRxStatus

#endif /* End (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) */

/* Only if TX is enabled */
#if(BT_Receiver_TX_ENABLED || BT_Receiver_HD_ENABLED)

    #if(BT_Receiver_TX_INTERRUPT_ENABLED)
        void BT_Receiver_EnableTxInt(void) ;
        void BT_Receiver_DisableTxInt(void) ;
        CY_ISR_PROTO(BT_Receiver_TXISR);
    #endif /* BT_Receiver_TX_INTERRUPT_ENABLED */

    void BT_Receiver_SetTxInterruptMode(uint8 intSrc) ;
    void BT_Receiver_WriteTxData(uint8 txDataByte) ;
    uint8 BT_Receiver_ReadTxStatus(void) ;
    void BT_Receiver_PutChar(uint8 txDataByte) ;
    void BT_Receiver_PutString(const char8 string[]) ;
    void BT_Receiver_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void BT_Receiver_PutCRLF(uint8 txDataByte) ;
    void BT_Receiver_ClearTxBuffer(void) ;
    void BT_Receiver_SetTxAddressMode(uint8 addressMode) ;
    void BT_Receiver_SendBreak(uint8 retMode) ;
    uint8 BT_Receiver_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define BT_Receiver_PutStringConst         BT_Receiver_PutString
    #define BT_Receiver_PutArrayConst          BT_Receiver_PutArray
    #define BT_Receiver_GetTxInterruptSource   BT_Receiver_ReadTxStatus

#endif /* End BT_Receiver_TX_ENABLED || BT_Receiver_HD_ENABLED */

#if(BT_Receiver_HD_ENABLED)
    void BT_Receiver_LoadRxConfig(void) ;
    void BT_Receiver_LoadTxConfig(void) ;
#endif /* End BT_Receiver_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_BT_Receiver) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    BT_Receiver_CyBtldrCommStart(void) CYSMALL ;
    void    BT_Receiver_CyBtldrCommStop(void) CYSMALL ;
    void    BT_Receiver_CyBtldrCommReset(void) CYSMALL ;
    cystatus BT_Receiver_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus BT_Receiver_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_BT_Receiver)
        #define CyBtldrCommStart    BT_Receiver_CyBtldrCommStart
        #define CyBtldrCommStop     BT_Receiver_CyBtldrCommStop
        #define CyBtldrCommReset    BT_Receiver_CyBtldrCommReset
        #define CyBtldrCommWrite    BT_Receiver_CyBtldrCommWrite
        #define CyBtldrCommRead     BT_Receiver_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_BT_Receiver) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define BT_Receiver_BYTE2BYTE_TIME_OUT (25u)

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define BT_Receiver_SET_SPACE                              (0x00u)
#define BT_Receiver_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (BT_Receiver_TX_ENABLED) || (BT_Receiver_HD_ENABLED) )
    #if(BT_Receiver_TX_INTERRUPT_ENABLED)
        #define BT_Receiver_TX_VECT_NUM            (uint8)BT_Receiver_TXInternalInterrupt__INTC_NUMBER
        #define BT_Receiver_TX_PRIOR_NUM           (uint8)BT_Receiver_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* BT_Receiver_TX_INTERRUPT_ENABLED */
    #if(BT_Receiver_TX_ENABLED)
        #define BT_Receiver_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define BT_Receiver_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define BT_Receiver_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define BT_Receiver_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* BT_Receiver_TX_ENABLED */
    #if(BT_Receiver_HD_ENABLED)
        #define BT_Receiver_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define BT_Receiver_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define BT_Receiver_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define BT_Receiver_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* BT_Receiver_HD_ENABLED */
    #define BT_Receiver_TX_STS_COMPLETE            (uint8)(0x01u << BT_Receiver_TX_STS_COMPLETE_SHIFT)
    #define BT_Receiver_TX_STS_FIFO_EMPTY          (uint8)(0x01u << BT_Receiver_TX_STS_FIFO_EMPTY_SHIFT)
    #define BT_Receiver_TX_STS_FIFO_FULL           (uint8)(0x01u << BT_Receiver_TX_STS_FIFO_FULL_SHIFT)
    #define BT_Receiver_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << BT_Receiver_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (BT_Receiver_TX_ENABLED) || (BT_Receiver_HD_ENABLED)*/

#if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
    #if(BT_Receiver_RX_INTERRUPT_ENABLED)
        #define BT_Receiver_RX_VECT_NUM            (uint8)BT_Receiver_RXInternalInterrupt__INTC_NUMBER
        #define BT_Receiver_RX_PRIOR_NUM           (uint8)BT_Receiver_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* BT_Receiver_RX_INTERRUPT_ENABLED */
    #define BT_Receiver_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define BT_Receiver_RX_STS_BREAK_SHIFT             (0x01u)
    #define BT_Receiver_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define BT_Receiver_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define BT_Receiver_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define BT_Receiver_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define BT_Receiver_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define BT_Receiver_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define BT_Receiver_RX_STS_MRKSPC           (uint8)(0x01u << BT_Receiver_RX_STS_MRKSPC_SHIFT)
    #define BT_Receiver_RX_STS_BREAK            (uint8)(0x01u << BT_Receiver_RX_STS_BREAK_SHIFT)
    #define BT_Receiver_RX_STS_PAR_ERROR        (uint8)(0x01u << BT_Receiver_RX_STS_PAR_ERROR_SHIFT)
    #define BT_Receiver_RX_STS_STOP_ERROR       (uint8)(0x01u << BT_Receiver_RX_STS_STOP_ERROR_SHIFT)
    #define BT_Receiver_RX_STS_OVERRUN          (uint8)(0x01u << BT_Receiver_RX_STS_OVERRUN_SHIFT)
    #define BT_Receiver_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << BT_Receiver_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define BT_Receiver_RX_STS_ADDR_MATCH       (uint8)(0x01u << BT_Receiver_RX_STS_ADDR_MATCH_SHIFT)
    #define BT_Receiver_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << BT_Receiver_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define BT_Receiver_RX_HW_MASK                     (0x7Fu)
#endif /* End (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) */

/* Control Register definitions */
#define BT_Receiver_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define BT_Receiver_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define BT_Receiver_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define BT_Receiver_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define BT_Receiver_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define BT_Receiver_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define BT_Receiver_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define BT_Receiver_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define BT_Receiver_CTRL_HD_SEND               (uint8)(0x01u << BT_Receiver_CTRL_HD_SEND_SHIFT)
#define BT_Receiver_CTRL_HD_SEND_BREAK         (uint8)(0x01u << BT_Receiver_CTRL_HD_SEND_BREAK_SHIFT)
#define BT_Receiver_CTRL_MARK                  (uint8)(0x01u << BT_Receiver_CTRL_MARK_SHIFT)
#define BT_Receiver_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << BT_Receiver_CTRL_PARITY_TYPE0_SHIFT)
#define BT_Receiver_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << BT_Receiver_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define BT_Receiver_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define BT_Receiver_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define BT_Receiver_SEND_BREAK                         (0x00u)
#define BT_Receiver_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define BT_Receiver_REINIT                             (0x02u)
#define BT_Receiver_SEND_WAIT_REINIT                   (0x03u)

#define BT_Receiver_OVER_SAMPLE_8                      (8u)
#define BT_Receiver_OVER_SAMPLE_16                     (16u)

#define BT_Receiver_BIT_CENTER                         (BT_Receiver_OVER_SAMPLE_COUNT - 1u)

#define BT_Receiver_FIFO_LENGTH                        (4u)
#define BT_Receiver_NUMBER_OF_START_BIT                (1u)
#define BT_Receiver_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation*/
#define BT_Receiver_TXBITCTR_BREAKBITS8X   ((BT_Receiver_BREAK_BITS_TX * BT_Receiver_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation*/
#define BT_Receiver_TXBITCTR_BREAKBITS ((BT_Receiver_BREAK_BITS_TX * BT_Receiver_OVER_SAMPLE_COUNT) - 1u)

#define BT_Receiver_HALF_BIT_COUNT   \
                            (((BT_Receiver_OVER_SAMPLE_COUNT / 2u) + (BT_Receiver_USE23POLLING * 1u)) - 2u)
#if (BT_Receiver_OVER_SAMPLE_COUNT == BT_Receiver_OVER_SAMPLE_8)
    #define BT_Receiver_HD_TXBITCTR_INIT   (((BT_Receiver_BREAK_BITS_TX + \
                            BT_Receiver_NUMBER_OF_START_BIT) * BT_Receiver_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define BT_Receiver_RXBITCTR_INIT  ((((BT_Receiver_BREAK_BITS_RX + BT_Receiver_NUMBER_OF_START_BIT) \
                            * BT_Receiver_OVER_SAMPLE_COUNT) + BT_Receiver_HALF_BIT_COUNT) - 1u)


#else /* BT_Receiver_OVER_SAMPLE_COUNT == BT_Receiver_OVER_SAMPLE_16 */
    #define BT_Receiver_HD_TXBITCTR_INIT   ((8u * BT_Receiver_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount=16 */
    #define BT_Receiver_RXBITCTR_INIT      (((7u * BT_Receiver_OVER_SAMPLE_COUNT) - 1u) + \
                                                      BT_Receiver_HALF_BIT_COUNT)
#endif /* End BT_Receiver_OVER_SAMPLE_COUNT */
#define BT_Receiver_HD_RXBITCTR_INIT                   BT_Receiver_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 BT_Receiver_initVar;
#if( BT_Receiver_TX_ENABLED && (BT_Receiver_TXBUFFERSIZE > BT_Receiver_FIFO_LENGTH))
    extern volatile uint8 BT_Receiver_txBuffer[BT_Receiver_TXBUFFERSIZE];
    extern volatile uint8 BT_Receiver_txBufferRead;
    extern uint8 BT_Receiver_txBufferWrite;
#endif /* End BT_Receiver_TX_ENABLED */
#if( ( BT_Receiver_RX_ENABLED || BT_Receiver_HD_ENABLED ) && \
     (BT_Receiver_RXBUFFERSIZE > BT_Receiver_FIFO_LENGTH) )
    extern volatile uint8 BT_Receiver_rxBuffer[BT_Receiver_RXBUFFERSIZE];
    extern volatile uint8 BT_Receiver_rxBufferRead;
    extern volatile uint8 BT_Receiver_rxBufferWrite;
    extern volatile uint8 BT_Receiver_rxBufferLoopDetect;
    extern volatile uint8 BT_Receiver_rxBufferOverflow;
    #if (BT_Receiver_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 BT_Receiver_rxAddressMode;
        extern volatile uint8 BT_Receiver_rxAddressDetected;
    #endif /* End EnableHWAddress */
#endif /* End BT_Receiver_RX_ENABLED */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define BT_Receiver__B_UART__AM_SW_BYTE_BYTE 1
#define BT_Receiver__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define BT_Receiver__B_UART__AM_HW_BYTE_BY_BYTE 3
#define BT_Receiver__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define BT_Receiver__B_UART__AM_NONE 0

#define BT_Receiver__B_UART__NONE_REVB 0
#define BT_Receiver__B_UART__EVEN_REVB 1
#define BT_Receiver__B_UART__ODD_REVB 2
#define BT_Receiver__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define BT_Receiver_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define BT_Receiver_NUMBER_OF_STOP_BITS    (1u)

#if (BT_Receiver_RXHW_ADDRESS_ENABLED)
    #define BT_Receiver_RXADDRESSMODE      (0u)
    #define BT_Receiver_RXHWADDRESS1       (0u)
    #define BT_Receiver_RXHWADDRESS2       (0u)
    /* Backward compatible define */
    #define BT_Receiver_RXAddressMode      BT_Receiver_RXADDRESSMODE
#endif /* End EnableHWAddress */

#define BT_Receiver_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((1 << BT_Receiver_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << BT_Receiver_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << BT_Receiver_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << BT_Receiver_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << BT_Receiver_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << BT_Receiver_RX_STS_BREAK_SHIFT) \
                                        | (0 << BT_Receiver_RX_STS_OVERRUN_SHIFT))

#define BT_Receiver_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << BT_Receiver_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << BT_Receiver_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << BT_Receiver_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << BT_Receiver_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define BT_Receiver_CONTROL_REG \
                            (* (reg8 *) BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define BT_Receiver_CONTROL_PTR \
                            (  (reg8 *) BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(BT_Receiver_TX_ENABLED)
    #define BT_Receiver_TXDATA_REG          (* (reg8 *) BT_Receiver_BUART_sTX_TxShifter_u0__F0_REG)
    #define BT_Receiver_TXDATA_PTR          (  (reg8 *) BT_Receiver_BUART_sTX_TxShifter_u0__F0_REG)
    #define BT_Receiver_TXDATA_AUX_CTL_REG  (* (reg8 *) BT_Receiver_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define BT_Receiver_TXDATA_AUX_CTL_PTR  (  (reg8 *) BT_Receiver_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define BT_Receiver_TXSTATUS_REG        (* (reg8 *) BT_Receiver_BUART_sTX_TxSts__STATUS_REG)
    #define BT_Receiver_TXSTATUS_PTR        (  (reg8 *) BT_Receiver_BUART_sTX_TxSts__STATUS_REG)
    #define BT_Receiver_TXSTATUS_MASK_REG   (* (reg8 *) BT_Receiver_BUART_sTX_TxSts__MASK_REG)
    #define BT_Receiver_TXSTATUS_MASK_PTR   (  (reg8 *) BT_Receiver_BUART_sTX_TxSts__MASK_REG)
    #define BT_Receiver_TXSTATUS_ACTL_REG   (* (reg8 *) BT_Receiver_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define BT_Receiver_TXSTATUS_ACTL_PTR   (  (reg8 *) BT_Receiver_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(BT_Receiver_TXCLKGEN_DP)
        #define BT_Receiver_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define BT_Receiver_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define BT_Receiver_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define BT_Receiver_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define BT_Receiver_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define BT_Receiver_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define BT_Receiver_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define BT_Receiver_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define BT_Receiver_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define BT_Receiver_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) BT_Receiver_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* BT_Receiver_TXCLKGEN_DP */

#endif /* End BT_Receiver_TX_ENABLED */

#if(BT_Receiver_HD_ENABLED)

    #define BT_Receiver_TXDATA_REG             (* (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__F1_REG )
    #define BT_Receiver_TXDATA_PTR             (  (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__F1_REG )
    #define BT_Receiver_TXDATA_AUX_CTL_REG     (* (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define BT_Receiver_TXDATA_AUX_CTL_PTR     (  (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define BT_Receiver_TXSTATUS_REG           (* (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_REG )
    #define BT_Receiver_TXSTATUS_PTR           (  (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_REG )
    #define BT_Receiver_TXSTATUS_MASK_REG      (* (reg8 *) BT_Receiver_BUART_sRX_RxSts__MASK_REG )
    #define BT_Receiver_TXSTATUS_MASK_PTR      (  (reg8 *) BT_Receiver_BUART_sRX_RxSts__MASK_REG )
    #define BT_Receiver_TXSTATUS_ACTL_REG      (* (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define BT_Receiver_TXSTATUS_ACTL_PTR      (  (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End BT_Receiver_HD_ENABLED */

#if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
    #define BT_Receiver_RXDATA_REG             (* (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__F0_REG )
    #define BT_Receiver_RXDATA_PTR             (  (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__F0_REG )
    #define BT_Receiver_RXADDRESS1_REG         (* (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__D0_REG )
    #define BT_Receiver_RXADDRESS1_PTR         (  (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__D0_REG )
    #define BT_Receiver_RXADDRESS2_REG         (* (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__D1_REG )
    #define BT_Receiver_RXADDRESS2_PTR         (  (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__D1_REG )
    #define BT_Receiver_RXDATA_AUX_CTL_REG     (* (reg8 *) BT_Receiver_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define BT_Receiver_RXBITCTR_PERIOD_REG    (* (reg8 *) BT_Receiver_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define BT_Receiver_RXBITCTR_PERIOD_PTR    (  (reg8 *) BT_Receiver_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define BT_Receiver_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) BT_Receiver_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define BT_Receiver_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) BT_Receiver_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define BT_Receiver_RXBITCTR_COUNTER_REG   (* (reg8 *) BT_Receiver_BUART_sRX_RxBitCounter__COUNT_REG )
    #define BT_Receiver_RXBITCTR_COUNTER_PTR   (  (reg8 *) BT_Receiver_BUART_sRX_RxBitCounter__COUNT_REG )

    #define BT_Receiver_RXSTATUS_REG           (* (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_REG )
    #define BT_Receiver_RXSTATUS_PTR           (  (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_REG )
    #define BT_Receiver_RXSTATUS_MASK_REG      (* (reg8 *) BT_Receiver_BUART_sRX_RxSts__MASK_REG )
    #define BT_Receiver_RXSTATUS_MASK_PTR      (  (reg8 *) BT_Receiver_BUART_sRX_RxSts__MASK_REG )
    #define BT_Receiver_RXSTATUS_ACTL_REG      (* (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define BT_Receiver_RXSTATUS_ACTL_PTR      (  (reg8 *) BT_Receiver_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) */

#if(BT_Receiver_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define BT_Receiver_INTCLOCK_CLKEN_REG     (* (reg8 *) BT_Receiver_IntClock__PM_ACT_CFG)
    #define BT_Receiver_INTCLOCK_CLKEN_PTR     (  (reg8 *) BT_Receiver_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define BT_Receiver_INTCLOCK_CLKEN_MASK    BT_Receiver_IntClock__PM_ACT_MSK
#endif /* End BT_Receiver_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(BT_Receiver_TX_ENABLED)
    #define BT_Receiver_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End BT_Receiver_TX_ENABLED */

#if(BT_Receiver_HD_ENABLED)
    #define BT_Receiver_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End BT_Receiver_HD_ENABLED */

#if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
    #define BT_Receiver_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) */


/***************************************
* Renamed global variables or defines
* for backward compatible
***************************************/

#define BT_Receiver_initvar                    BT_Receiver_initVar

#define BT_Receiver_RX_Enabled                 BT_Receiver_RX_ENABLED
#define BT_Receiver_TX_Enabled                 BT_Receiver_TX_ENABLED
#define BT_Receiver_HD_Enabled                 BT_Receiver_HD_ENABLED
#define BT_Receiver_RX_IntInterruptEnabled     BT_Receiver_RX_INTERRUPT_ENABLED
#define BT_Receiver_TX_IntInterruptEnabled     BT_Receiver_TX_INTERRUPT_ENABLED
#define BT_Receiver_InternalClockUsed          BT_Receiver_INTERNAL_CLOCK_USED
#define BT_Receiver_RXHW_Address_Enabled       BT_Receiver_RXHW_ADDRESS_ENABLED
#define BT_Receiver_OverSampleCount            BT_Receiver_OVER_SAMPLE_COUNT
#define BT_Receiver_ParityType                 BT_Receiver_PARITY_TYPE

#if( BT_Receiver_TX_ENABLED && (BT_Receiver_TXBUFFERSIZE > BT_Receiver_FIFO_LENGTH))
    #define BT_Receiver_TXBUFFER               BT_Receiver_txBuffer
    #define BT_Receiver_TXBUFFERREAD           BT_Receiver_txBufferRead
    #define BT_Receiver_TXBUFFERWRITE          BT_Receiver_txBufferWrite
#endif /* End BT_Receiver_TX_ENABLED */
#if( ( BT_Receiver_RX_ENABLED || BT_Receiver_HD_ENABLED ) && \
     (BT_Receiver_RXBUFFERSIZE > BT_Receiver_FIFO_LENGTH) )
    #define BT_Receiver_RXBUFFER               BT_Receiver_rxBuffer
    #define BT_Receiver_RXBUFFERREAD           BT_Receiver_rxBufferRead
    #define BT_Receiver_RXBUFFERWRITE          BT_Receiver_rxBufferWrite
    #define BT_Receiver_RXBUFFERLOOPDETECT     BT_Receiver_rxBufferLoopDetect
    #define BT_Receiver_RXBUFFER_OVERFLOW      BT_Receiver_rxBufferOverflow
#endif /* End BT_Receiver_RX_ENABLED */

#ifdef BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define BT_Receiver_CONTROL                BT_Receiver_CONTROL_REG
#endif /* End BT_Receiver_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(BT_Receiver_TX_ENABLED)
    #define BT_Receiver_TXDATA                 BT_Receiver_TXDATA_REG
    #define BT_Receiver_TXSTATUS               BT_Receiver_TXSTATUS_REG
    #define BT_Receiver_TXSTATUS_MASK          BT_Receiver_TXSTATUS_MASK_REG
    #define BT_Receiver_TXSTATUS_ACTL          BT_Receiver_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(BT_Receiver_TXCLKGEN_DP)
        #define BT_Receiver_TXBITCLKGEN_CTR        BT_Receiver_TXBITCLKGEN_CTR_REG
        #define BT_Receiver_TXBITCLKTX_COMPLETE    BT_Receiver_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define BT_Receiver_TXBITCTR_PERIOD        BT_Receiver_TXBITCTR_PERIOD_REG
        #define BT_Receiver_TXBITCTR_CONTROL       BT_Receiver_TXBITCTR_CONTROL_REG
        #define BT_Receiver_TXBITCTR_COUNTER       BT_Receiver_TXBITCTR_COUNTER_REG
    #endif /* BT_Receiver_TXCLKGEN_DP */
#endif /* End BT_Receiver_TX_ENABLED */

#if(BT_Receiver_HD_ENABLED)
    #define BT_Receiver_TXDATA                 BT_Receiver_TXDATA_REG
    #define BT_Receiver_TXSTATUS               BT_Receiver_TXSTATUS_REG
    #define BT_Receiver_TXSTATUS_MASK          BT_Receiver_TXSTATUS_MASK_REG
    #define BT_Receiver_TXSTATUS_ACTL          BT_Receiver_TXSTATUS_ACTL_REG
#endif /* End BT_Receiver_HD_ENABLED */

#if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
    #define BT_Receiver_RXDATA                 BT_Receiver_RXDATA_REG
    #define BT_Receiver_RXADDRESS1             BT_Receiver_RXADDRESS1_REG
    #define BT_Receiver_RXADDRESS2             BT_Receiver_RXADDRESS2_REG
    #define BT_Receiver_RXBITCTR_PERIOD        BT_Receiver_RXBITCTR_PERIOD_REG
    #define BT_Receiver_RXBITCTR_CONTROL       BT_Receiver_RXBITCTR_CONTROL_REG
    #define BT_Receiver_RXBITCTR_COUNTER       BT_Receiver_RXBITCTR_COUNTER_REG
    #define BT_Receiver_RXSTATUS               BT_Receiver_RXSTATUS_REG
    #define BT_Receiver_RXSTATUS_MASK          BT_Receiver_RXSTATUS_MASK_REG
    #define BT_Receiver_RXSTATUS_ACTL          BT_Receiver_RXSTATUS_ACTL_REG
#endif /* End  (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) */

#if(BT_Receiver_INTERNAL_CLOCK_USED)
    #define BT_Receiver_INTCLOCK_CLKEN         BT_Receiver_INTCLOCK_CLKEN_REG
#endif /* End BT_Receiver_INTERNAL_CLOCK_USED */

#define BT_Receiver_WAIT_FOR_COMLETE_REINIT    BT_Receiver_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_BT_Receiver_H */


/* [] END OF FILE */
