/*******************************************************************************
* File Name: BT_Receiver_PM.c
* Version 2.30
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "BT_Receiver.h"


/***************************************
* Local data allocation
***************************************/

static BT_Receiver_BACKUP_STRUCT  BT_Receiver_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: BT_Receiver_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BT_Receiver_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BT_Receiver_SaveConfig(void)
{
    #if (CY_UDB_V0)

        #if(BT_Receiver_CONTROL_REG_REMOVED == 0u)
            BT_Receiver_backup.cr = BT_Receiver_CONTROL_REG;
        #endif /* End BT_Receiver_CONTROL_REG_REMOVED */

        #if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
            BT_Receiver_backup.rx_period = BT_Receiver_RXBITCTR_PERIOD_REG;
            BT_Receiver_backup.rx_mask = BT_Receiver_RXSTATUS_MASK_REG;
            #if (BT_Receiver_RXHW_ADDRESS_ENABLED)
                BT_Receiver_backup.rx_addr1 = BT_Receiver_RXADDRESS1_REG;
                BT_Receiver_backup.rx_addr2 = BT_Receiver_RXADDRESS2_REG;
            #endif /* End BT_Receiver_RXHW_ADDRESS_ENABLED */
        #endif /* End BT_Receiver_RX_ENABLED | BT_Receiver_HD_ENABLED*/

        #if(BT_Receiver_TX_ENABLED)
            #if(BT_Receiver_TXCLKGEN_DP)
                BT_Receiver_backup.tx_clk_ctr = BT_Receiver_TXBITCLKGEN_CTR_REG;
                BT_Receiver_backup.tx_clk_compl = BT_Receiver_TXBITCLKTX_COMPLETE_REG;
            #else
                BT_Receiver_backup.tx_period = BT_Receiver_TXBITCTR_PERIOD_REG;
            #endif /*End BT_Receiver_TXCLKGEN_DP */
            BT_Receiver_backup.tx_mask = BT_Receiver_TXSTATUS_MASK_REG;
        #endif /*End BT_Receiver_TX_ENABLED */


    #else /* CY_UDB_V1 */

        #if(BT_Receiver_CONTROL_REG_REMOVED == 0u)
            BT_Receiver_backup.cr = BT_Receiver_CONTROL_REG;
        #endif /* End BT_Receiver_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: BT_Receiver_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BT_Receiver_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BT_Receiver_RestoreConfig(void)
{

    #if (CY_UDB_V0)

        #if(BT_Receiver_CONTROL_REG_REMOVED == 0u)
            BT_Receiver_CONTROL_REG = BT_Receiver_backup.cr;
        #endif /* End BT_Receiver_CONTROL_REG_REMOVED */

        #if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
            BT_Receiver_RXBITCTR_PERIOD_REG = BT_Receiver_backup.rx_period;
            BT_Receiver_RXSTATUS_MASK_REG = BT_Receiver_backup.rx_mask;
            #if (BT_Receiver_RXHW_ADDRESS_ENABLED)
                BT_Receiver_RXADDRESS1_REG = BT_Receiver_backup.rx_addr1;
                BT_Receiver_RXADDRESS2_REG = BT_Receiver_backup.rx_addr2;
            #endif /* End BT_Receiver_RXHW_ADDRESS_ENABLED */
        #endif  /* End (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) */

        #if(BT_Receiver_TX_ENABLED)
            #if(BT_Receiver_TXCLKGEN_DP)
                BT_Receiver_TXBITCLKGEN_CTR_REG = BT_Receiver_backup.tx_clk_ctr;
                BT_Receiver_TXBITCLKTX_COMPLETE_REG = BT_Receiver_backup.tx_clk_compl;
            #else
                BT_Receiver_TXBITCTR_PERIOD_REG = BT_Receiver_backup.tx_period;
            #endif /*End BT_Receiver_TXCLKGEN_DP */
            BT_Receiver_TXSTATUS_MASK_REG = BT_Receiver_backup.tx_mask;
        #endif /*End BT_Receiver_TX_ENABLED */

    #else /* CY_UDB_V1 */

        #if(BT_Receiver_CONTROL_REG_REMOVED == 0u)
            BT_Receiver_CONTROL_REG = BT_Receiver_backup.cr;
        #endif /* End BT_Receiver_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: BT_Receiver_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called
*  just prior to entering sleep.
*
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BT_Receiver_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BT_Receiver_Sleep(void)
{

    #if(BT_Receiver_RX_ENABLED || BT_Receiver_HD_ENABLED)
        if((BT_Receiver_RXSTATUS_ACTL_REG  & BT_Receiver_INT_ENABLE) != 0u)
        {
            BT_Receiver_backup.enableState = 1u;
        }
        else
        {
            BT_Receiver_backup.enableState = 0u;
        }
    #else
        if((BT_Receiver_TXSTATUS_ACTL_REG  & BT_Receiver_INT_ENABLE) !=0u)
        {
            BT_Receiver_backup.enableState = 1u;
        }
        else
        {
            BT_Receiver_backup.enableState = 0u;
        }
    #endif /* End BT_Receiver_RX_ENABLED || BT_Receiver_HD_ENABLED*/

    BT_Receiver_Stop();
    BT_Receiver_SaveConfig();
}


/*******************************************************************************
* Function Name: BT_Receiver_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BT_Receiver_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BT_Receiver_Wakeup(void)
{
    BT_Receiver_RestoreConfig();
    #if( (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) )
        BT_Receiver_ClearRxBuffer();
    #endif /* End (BT_Receiver_RX_ENABLED) || (BT_Receiver_HD_ENABLED) */
    #if(BT_Receiver_TX_ENABLED || BT_Receiver_HD_ENABLED)
        BT_Receiver_ClearTxBuffer();
    #endif /* End BT_Receiver_TX_ENABLED || BT_Receiver_HD_ENABLED */

    if(BT_Receiver_backup.enableState != 0u)
    {
        BT_Receiver_Enable();
    }
}


/* [] END OF FILE */
