/*******************************************************************************
* File Name: BT_Rx.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <BT_Rx.H>

#if !defined(BT_Rx__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START BT_Rx_intc` */
#include "BT_Receiver.h"
uint8 BT_Rx = 0, Rx_flag = 0;
/* `#END` */

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: BT_Rx_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_Start(void)
{
    /* For all we know the interrupt is active. */
    BT_Rx_Disable();

    /* Set the ISR to point to the BT_Rx Interrupt. */
    BT_Rx_SetVector(&BT_Rx_Interrupt);

    /* Set the priority. */
    BT_Rx_SetPriority((uint8)BT_Rx_INTC_PRIOR_NUMBER);

    /* Enable it. */
    BT_Rx_Enable();
}


/*******************************************************************************
* Function Name: BT_Rx_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    BT_Rx_Disable();

    /* Set the ISR to point to the BT_Rx Interrupt. */
    BT_Rx_SetVector(address);

    /* Set the priority. */
    BT_Rx_SetPriority((uint8)BT_Rx_INTC_PRIOR_NUMBER);

    /* Enable it. */
    BT_Rx_Enable();
}


/*******************************************************************************
* Function Name: BT_Rx_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_Stop(void)
{
    /* Disable this interrupt. */
    BT_Rx_Disable();

    /* Set the ISR to point to the passive one. */
    BT_Rx_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: BT_Rx_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for BT_Rx.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(BT_Rx_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START BT_Rx_Interrupt` */
	BT_Rx = BT_Receiver_ReadRxData();
	Rx_flag = 1;
    /* `#END` */
}


/*******************************************************************************
* Function Name: BT_Rx_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling BT_Rx_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use BT_Rx_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_SetVector(cyisraddress address)
{
    CyRamVectors[CYINT_IRQ_BASE + BT_Rx__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: BT_Rx_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress BT_Rx_GetVector(void)
{
    return CyRamVectors[CYINT_IRQ_BASE + BT_Rx__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: BT_Rx_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling BT_Rx_Start
*   or BT_Rx_StartEx will override any effect this method would 
*   have had. This method should only be called after BT_Rx_Start or 
*   BT_Rx_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 3, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_SetPriority(uint8 priority)
{
	uint8 interruptState;
    uint32 priorityOffset = ((BT_Rx__INTC_NUMBER % 4u) * 8u) + 6u;
    
	interruptState = CyEnterCriticalSection();
    *BT_Rx_INTC_PRIOR = (*BT_Rx_INTC_PRIOR & (uint32)(~BT_Rx__INTC_PRIOR_MASK)) |
                                    ((uint32)priority << priorityOffset);
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: BT_Rx_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 3, 0 being the highest.
*
*******************************************************************************/
uint8 BT_Rx_GetPriority(void)
{
    uint32 priority;
	uint32 priorityOffset = ((BT_Rx__INTC_NUMBER % 4u) * 8u) + 6u;

    priority = (*BT_Rx_INTC_PRIOR & BT_Rx__INTC_PRIOR_MASK) >> priorityOffset;

    return (uint8)priority;
}


/*******************************************************************************
* Function Name: BT_Rx_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_Enable(void)
{
    /* Enable the general interrupt. */
    *BT_Rx_INTC_SET_EN = BT_Rx__INTC_MASK;
}


/*******************************************************************************
* Function Name: BT_Rx_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 BT_Rx_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*BT_Rx_INTC_SET_EN & (uint32)BT_Rx__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: BT_Rx_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_Disable(void)
{
    /* Disable the general interrupt. */
    *BT_Rx_INTC_CLR_EN = BT_Rx__INTC_MASK;
}


/*******************************************************************************
* Function Name: BT_Rx_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_SetPending(void)
{
    *BT_Rx_INTC_SET_PD = BT_Rx__INTC_MASK;
}


/*******************************************************************************
* Function Name: BT_Rx_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_Rx_ClearPending(void)
{
    *BT_Rx_INTC_CLR_PD = BT_Rx__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
