/*******************************************************************************
* File Name: Joystick.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Joystick.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        Joystick_PC =   (Joystick_PC & \
                                (uint32)(~(uint32)(Joystick_DRIVE_MODE_IND_MASK << (Joystick_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (Joystick_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: Joystick_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Joystick_Write(uint8 value) 
{
    uint8 drVal = (uint8)(Joystick_DR & (uint8)(~Joystick_MASK));
    drVal = (drVal | ((uint8)(value << Joystick_SHIFT) & Joystick_MASK));
    Joystick_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: Joystick_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Joystick_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(Joystick__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: Joystick_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Joystick_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Joystick_Read(void) 
{
    return (uint8)((Joystick_PS & Joystick_MASK) >> Joystick_SHIFT);
}


/*******************************************************************************
* Function Name: Joystick_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Joystick_ReadDataReg(void) 
{
    return (uint8)((Joystick_DR & Joystick_MASK) >> Joystick_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Joystick_INTSTAT) 

    /*******************************************************************************
    * Function Name: Joystick_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Joystick_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(Joystick_INTSTAT & Joystick_MASK);
		Joystick_INTSTAT = maskedStatus;
        return maskedStatus >> Joystick_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
