/*******************************************************************************
* File Name: Vdd.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Vdd.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        Vdd_PC =   (Vdd_PC & \
                                (uint32)(~(uint32)(Vdd_DRIVE_MODE_IND_MASK << (Vdd_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (Vdd_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: Vdd_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Vdd_Write(uint8 value) 
{
    uint8 drVal = (uint8)(Vdd_DR & (uint8)(~Vdd_MASK));
    drVal = (drVal | ((uint8)(value << Vdd_SHIFT) & Vdd_MASK));
    Vdd_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: Vdd_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Vdd_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(Vdd__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: Vdd_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Vdd_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Vdd_Read(void) 
{
    return (uint8)((Vdd_PS & Vdd_MASK) >> Vdd_SHIFT);
}


/*******************************************************************************
* Function Name: Vdd_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Vdd_ReadDataReg(void) 
{
    return (uint8)((Vdd_DR & Vdd_MASK) >> Vdd_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Vdd_INTSTAT) 

    /*******************************************************************************
    * Function Name: Vdd_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Vdd_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(Vdd_INTSTAT & Vdd_MASK);
		Vdd_INTSTAT = maskedStatus;
        return maskedStatus >> Vdd_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
