/*******************************************************************************
* File Name: Vss.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Vss.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        Vss_PC =   (Vss_PC & \
                                (uint32)(~(uint32)(Vss_DRIVE_MODE_IND_MASK << (Vss_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (Vss_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: Vss_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Vss_Write(uint8 value) 
{
    uint8 drVal = (uint8)(Vss_DR & (uint8)(~Vss_MASK));
    drVal = (drVal | ((uint8)(value << Vss_SHIFT) & Vss_MASK));
    Vss_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: Vss_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Vss_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(Vss__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: Vss_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Vss_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Vss_Read(void) 
{
    return (uint8)((Vss_PS & Vss_MASK) >> Vss_SHIFT);
}


/*******************************************************************************
* Function Name: Vss_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Vss_ReadDataReg(void) 
{
    return (uint8)((Vss_DR & Vss_MASK) >> Vss_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Vss_INTSTAT) 

    /*******************************************************************************
    * Function Name: Vss_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Vss_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(Vss_INTSTAT & Vss_MASK);
		Vss_INTSTAT = maskedStatus;
        return maskedStatus >> Vss_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
